@@ -319,10 +319,11 @@ const Application = new Lang.Class({
         if (data)
             return data;
 
-        let params = account.dup_parameters_vardict().deep_unpack();
-        let server = params['server'].deep_unpack();
-        let accountName = params['account'].deep_unpack();
-        Utils.debug('Failed to connect to %s with username %s'.format(server, accountName));
+        let params = Connections.getAccountParams(account);
+        let server = params['server'];
+        let accountName = params['account'];
+        let port = params['port'];
+        debug('Failed to connect to %s with username %s'.format(server, accountName));
 
         let accountServers = [];
         if (this._networksManager.getAccountIsPredefined(account))
@@ -331,7 +332,8 @@ const Application = new Lang.Class({
         data = {
             retry: 0,
             originalAccountName: accountName,
-            alternateServers: accountServers.filter(s => s.address != server)
+            alternateServers: accountServers.filter(s => s.address != server ||
+                                                         s.port != port)
         };
         this._retryData.set(account.object_path, data);
         return data;
@@ -365,7 +367,7 @@ const Application = new Lang.Class({
         let oldParams = account.dup_parameters_vardict().deep_unpack();
         let nick = oldParams['account'].deep_unpack();
 
-        Utils.debug('Retrying with nickname %s'.format(nick + '_'));
+        debug('Retrying with nickname %s'.format(nick + '_'));
         let params = { account: new GLib.Variant('s', nick + '_') };
         this._retryWithParams(account, new GLib.Variant('a{sv}', params));
         return true;
@@ -378,7 +380,7 @@ const Application = new Lang.Class({
         if (!server)
             return false;
 
-        Utils.debug('Retrying with %s:%d'.format(server.address, server.port));
+        debug('Retrying with %s:%d'.format(server.address, server.port));
         let params = { server: new GLib.Variant('s', server.address),
                        port: new GLib.Variant('u', server.port),
                        'use-ssl': new GLib.Variant('b', server.ssl) };
@@ -406,8 +408,8 @@ const Application = new Lang.Class({
 
             if (reason != Tp.ConnectionStatusReason.REQUESTED) {
                 let strReasons = Object.keys(Tp.ConnectionStatusReason);
-                Utils.debug('Account %s disconnected with reason %s'.format(
-                            account.display_name, strReasons[reason]));
+                debug('Account %s disconnected with reason %s'.format(
+                      account.display_name, strReasons[reason]));
             }
         }
 
