@@ -256,6 +256,7 @@ const ChatView = new Lang.Class({
                      Lang.bind(this, this._onStyleUpdated));
         this._onStyleUpdated();
 
+        this.connect('destroy', Lang.bind(this, this._onDestroy));
         this.connect('screen-changed',
                      Lang.bind(this, this._updateIndent));
         this.connect('scroll-event', Lang.bind(this, this._onScroll));
@@ -320,7 +321,8 @@ const ChatView = new Lang.Class({
         this._app.connect('room-focus-changed',
                           Lang.bind(this, this._checkMessages));
 
-        this._hoverCursor = Gdk.Cursor.new(Gdk.CursorType.HAND1);
+        this._hoverCursor = Gdk.Cursor.new_from_name(this.get_display(),
+                                                     'pointer');
 
         this._channelSignals = [];
         this._channel = null;
@@ -452,9 +454,7 @@ const ChatView = new Lang.Class({
         this._foreachNickTag(t => { this._updateTagStatus(t); });
     },
 
-    vfunc_destroy: function() {
-        this.parent();
-
+    _onDestroy: function() {
         for (let i = 0; i < this._channelSignals.length; i++)
             this._channel.disconnect(this._channelSignals[i]);
         this._channelSignals = [];
@@ -1257,6 +1257,16 @@ const ChatView = new Lang.Class({
         let server = params.server.deep_unpack();
 
         let text = message.text;
+
+        // mask identify passwords in private chats
+        if (this._room.type == Tp.HandleType.CONTACT) {
+            let [isIdentify, username, password] =
+                Polari.util_match_identify_message(text);
+
+            if (isIdentify)
+                text = text.replace(password, (p) => p.replace(/./g, '●'));
+        }
+
         let channels = Utils.findChannels(text, server);
         let urls = Utils.findUrls(text).concat(channels).sort((u1,u2) => u1.pos - u2.pos);
         let pos = 0;
