@@ -53,13 +53,12 @@ const IMGUR_CLIENT_ID = '4109e59177ec95e';
 const _balancedParens = '\\((?:[^\\s()<>]+|(?:\\(?:[^\\s()<>]+\\)))*\\)';
 const _leadingJunk = '[\\s`(\\[{\'\\"<\u00AB\u201C\u2018]';
 const _notTrailingJunk = '[^\\s`!()\\[\\]{};:\'\\".,<>?\u00AB\u00BB\u201C\u201D\u2018\u2019]';
-const _uriList = getURISchemes();
 
 const _urlRegexp = new RegExp(
     '(^|' + _leadingJunk + ')' +
     '(' +
         '(?:' +
-            '(?:' + _uriList.join('|') + '):' +   // scheme:
+            '(?:[a-z]+):' +                       // scheme:
             '|' +
             'www\\d{0,3}[.]' +                    // www.
             '|' +
@@ -79,40 +78,6 @@ const _urlRegexp = new RegExp(
 
 const _channelRegexp = new RegExp('(^| )#([\\w\\+\\.-]+)','g');
 
-let debugInit = false;
-let debugEnabled = false;
-
-function debug(str) {
-    if (!debugInit) {
-        let env = GLib.getenv('POLARI_DEBUG');
-        if (env)
-            debugEnabled = true;
-
-        debugInit = true;
-    }
-
-    if (debugEnabled)
-        log('DEBUG: ' + str);
-}
-
-function getURISchemes() {
-    let apps = Gio.AppInfo.get_all();
-    let prefix = 'x-scheme-handler/';
-    let schemes = [];
-
-    apps.forEach(function(app) {
-        let types = app.get_supported_types();
-        if (!types)
-            return;
-
-        types.forEach(function(type) {
-            if (type.startsWith(prefix))
-                schemes.push(type.replace(prefix, ''));
-        });
-    });
-    return schemes;
-}
-
 function getTpEventTime() {
     let time = Gtk.get_current_event_time ();
     if (time == 0)
